
#ifndef __A16CH_LIB_H_____
#define __A16CH_LIB_H_____

#ifdef __cplusplus
extern "C" {
#endif

#define	BYTE	unsigned char
#define WORD	unsigned short
#define DWORD	unsigned long




__declspec( dllexport ) BOOL ADDA_Init();
__declspec( dllexport ) BOOL ADDA_End();


__declspec( dllexport ) int ADDA_GetMaxCards();
__declspec( dllexport ) int ADDA_GetMaxChannels(int card_num);
__declspec( dllexport ) int ADDA_GetID(int card_num);

__declspec( dllexport ) int ADDA_WriteReg(int card_num,DWORD offset,DWORD data);
__declspec( dllexport ) int ADDA_ReadReg(int card_num,DWORD offset,DWORD *data);

__declspec( dllexport ) int ADDA_InIrqSet(int card_num,DWORD ipen, DWORD inen);
__declspec( dllexport ) int ADDA_InRead(int card_num,DWORD *data);
__declspec( dllexport ) int ADDA_InReadOvl(int card_num,DWORD *data,DWORD *status);
__declspec( dllexport ) int ADDA_CancelReadOvl(int card_num);

__declspec( dllexport ) int ADDA_OutWrite(int card_num,DWORD data);

// DAC 16 channel, ADC 16 channel parameter meaning
__declspec( dllexport ) int ADDA_GetDacBuf(int card_num,int channel,BYTE **Buf);
__declspec( dllexport ) int ADDA_DmaDacStart(int card_num,int channel,DWORD length,int sample_rate);
__declspec( dllexport ) int ADDA_DmaDacStop(int card_num,int channel);
__declspec( dllexport ) int ADDA_GetDmaDacPosOvl(int card_num,int channel,DWORD *pos);
__declspec( dllexport ) int ADDA_CancelGetDmaDacPos(int card_num,int channel);
__declspec( dllexport ) int ADDA_SetDacSigned(int card_num,DWORD flags);	// bit 0 to 15 defines each DAC channel's data signed or unsigned

// ADC 16 channel
__declspec( dllexport ) int ADDA_GetAdcBuf(int card_num,int channel,BYTE **Buf);
__declspec( dllexport ) int ADDA_DmaAdcStart(int card_num,int channel,DWORD length,int sample_rate);	// length is DMA block length
__declspec( dllexport ) int ADDA_DmaAdcStop(int card_num,int channel);
__declspec( dllexport ) int ADDA_GetDmaAdcPosOvl(int card_num,int channel,DWORD *pos);
__declspec( dllexport ) int ADDA_CancelGetDmaAdcPos(int card_num,int channel);
__declspec( dllexport ) int ADDA_SetAdcSigned(int card_num,DWORD flags);	// bit 0 to 15 defines each ADC channel's data is signed or unsigned

__declspec( dllexport ) int ADDA_PutDac(int card_num,int channel,WORD data);
__declspec( dllexport ) int ADDA_GetAdc(int card_num,int channel,WORD *data);		// read Adc then request new adc
__declspec( dllexport ) int ADDA_ReqReadAdc(int card_num,int channel,WORD *data);	// request ADC then read the result

__declspec( dllexport ) int ADDA_ReqAdc(int card_num,int chan_bits);				// channel bit flag
__declspec( dllexport ) int ADDA_IsAdcEnded(int card_num,int channel);			// return 1 if ok
__declspec( dllexport ) int ADDA_ReadAdc(int card_num,int channel,WORD *data);

__declspec( dllexport ) int ADDA_SetAdcSingleMode(int card_num,DWORD flags);	// bit 0 to 15 defines each ADC channel's single input mode or not



// eeprom program 
__declspec( dllexport ) void ADDA_SetRpt(int card_num,eepReport *report);
__declspec( dllexport ) int ADDA_Prog(int card_num,char *filename);


// ADC trigger control functions
__declspec( dllexport ) void ADDA_SetTrgSrc(int card_num,int channel,DWORD src);

// position controller 
__declspec( dllexport ) void ADDA_SetPosIrqEnable(int card_num,DWORD data);	// bit flags for each channel
__declspec( dllexport ) int	ADDA_GetPosition(int card_num,int channel,DWORD *pos);
__declspec( dllexport ) DWORD ADDA_GetPosStatus(int card_num);
__declspec( dllexport ) void ADDA_ClrPosStatus(int card_num,DWORD data);

// analog trigger event generator
__declspec( dllexport ) void ADDA_SetAnalogPara(int card_num,int channel,int mode,int ref_value);
__declspec( dllexport ) DWORD ADDA_GetAnalogTrgStatus(int card_num);
__declspec( dllexport ) void ADDA_ClrAnalogTrg(int card_num,DWORD data);

// digital trigger event generator
__declspec( dllexport ) void ADDA_SetDigitalPara(int card_num,DWORD pen,DWORD nen);
__declspec( dllexport ) DWORD ADDA_GetDigitalTrgStatus(int card_num);
__declspec( dllexport ) void ADDA_ClrDigitalTrg(int card_num,DWORD data);


// counter & timer 
__declspec( dllexport ) void ADDA_SetCounterPara(int card_num,int encoder_mode,int src,DWORD reload_value);
__declspec( dllexport ) void ADDA_SetCounterIrqMode(int card_num,int ien);
__declspec( dllexport ) DWORD ADDA_GetCounterStatus(int card_num);
__declspec( dllexport ) void ADDA_AckCounterStatus(int card_num,DWORD data);
__declspec( dllexport ) DWORD ADDA_GetEncoderValue(int card_num);


// trigger overlapped event control functions
__declspec( dllexport ) int ADDA_GetPositionOvl(int card_num,int channel, DWORD *pos);
__declspec( dllexport ) int	ADDA_CancelGetPositionOvl(int card_num,int channel);
__declspec( dllexport ) int ADDA_WaitCountOvl(int card_num);
__declspec( dllexport ) int ADDA_CancelWaitCountOvl(int card_num);

__declspec( dllexport ) BYTE *ADDA_GetIoStart(int card_num);



#ifdef __cplusplus
}
#endif

#endif
